@@ -51,7 +51,7 @@ class AtlantisClient:
         :return: Chave pública
         :rtype: str
         """
-        response = requests.get('{}/api/key'.format(self.atlantis_url))
+        response = requests.get('{}/api/public-key'.format(self.atlantis_url))
         response.raise_for_status()
         return response.json()
 
@@ -85,7 +85,7 @@ class AtlantisClient:
 
         :param access_token: Token do usuário gerado pelo Atlantis
         :type access_token: str
-        :return: Retorna dados do token: ``active``, ``email``, ``scope``, ``client_id``,``exp``, etc..
+        :return: Retorna dados do token: ``active``, ``email``, ``scope``, ``client_id``, ``exp``, etc..
         :rtype: dict
         """
         response = requests.post(
